summaryrefslogtreecommitdiff
path: root/fs/notify/inotify/inotify.h
diff options
context:
space:
mode:
authorEric Paris <eparis@redhat.com>2009-12-18 02:24:24 (GMT)
committerEric Paris <eparis@redhat.com>2010-07-28 13:58:53 (GMT)
commite61ce86737b4d60521e4e71f9892fe4bdcfb688b (patch)
treea1aba411504ac028d4ead6f28ca05bd024c74142 /fs/notify/inotify/inotify.h
parent72acc854427948efed7a83da27f7dc3239ac9afc (diff)
downloadlinux-e61ce86737b4d60521e4e71f9892fe4bdcfb688b.tar.xz
fsnotify: rename fsnotify_mark_entry to just fsnotify_mark
The name is long and it serves no real purpose. So rename fsnotify_mark_entry to just fsnotify_mark. Signed-off-by: Eric Paris <eparis@redhat.com>
Diffstat (limited to 'fs/notify/inotify/inotify.h')
-rw-r--r--fs/notify/inotify/inotify.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/fs/notify/inotify/inotify.h b/fs/notify/inotify/inotify.h
index f234f3a..07be6df 100644
--- a/fs/notify/inotify/inotify.h
+++ b/fs/notify/inotify/inotify.h
@@ -10,12 +10,12 @@ struct inotify_event_private_data {
};
struct inotify_inode_mark_entry {
- /* fsnotify_mark_entry MUST be the first thing */
- struct fsnotify_mark_entry fsn_entry;
+ /* fsnotify_mark MUST be the first thing */
+ struct fsnotify_mark fsn_entry;
int wd;
};
-extern void inotify_ignored_and_remove_idr(struct fsnotify_mark_entry *entry,
+extern void inotify_ignored_and_remove_idr(struct fsnotify_mark *entry,
struct fsnotify_group *group);
extern void inotify_free_event_priv(struct fsnotify_event_private_data *event_priv);